@@ -2,9 +2,9 @@
 
 ;; Copyright (C) 2024-2026 James Cherti | https://www.jamescherti.com/contact/
 
-;; Author: James Cherti
-;; Package-Version: 20260114.1601
-;; Package-Revision: 59b431c6a55b
+;; Author: James Cherti <https://www.jamescherti.com/contact/>
+;; Package-Version: 20260215.2153
+;; Package-Revision: 4de82266d54b
 ;; URL: https://github.com/jamescherti/compile-angel.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "26.3"))
@@ -500,13 +500,17 @@ Return the byte compile result."
                              (let ((combined-args (cons format-string
                                                         messages-args)))
                                (when (or (not compile-angel--quiet-byte-compile)
+                                         ;; Ensure format-string is a string
+                                         ;; before checking prefixes. This
+                                         ;; prevents crashes on (message nil).
                                          (and compile-angel--quiet-byte-compile
-                                              (and (not (string-prefix-p
-                                                         "Wrote"
-                                                         format-string))
-                                                   (not (string-prefix-p
-                                                         "Compiling "
-                                                         format-string)))))
+                                              (stringp format-string)
+                                              (not (string-prefix-p
+                                                    "Wrote"
+                                                    format-string))
+                                              (not (string-prefix-p
+                                                    "Compiling "
+                                                    format-string))))
                                  ;; Show the message
                                  (apply original-message combined-args))))))
                 (condition-case err
@@ -1425,6 +1429,8 @@ the corresponding .elc or .eln filenames."
       (progn
         ;; Init
         (compile-angel--init)
+        ;; Problematic files
+        (compile-angel--entry-point nil 'dash)
         ;; Compile features
         (when compile-angel-on-load-compile-features
           (compile-angel--compile-loaded-features))
